@@ -60,7 +60,7 @@ CellRendererPopup::CellRendererPopup()
 
   popup_window_.signal_button_press_event().connect(sigc::mem_fun(*this, &Self::on_button_press_event));
   popup_window_.signal_key_press_event   ().connect(sigc::mem_fun(*this, &Self::on_key_press_event));
-  popup_window_.signal_style_changed     ().connect(sigc::mem_fun(*this, &Self::on_style_changed));
+  //TODO: popup_window_.signal_style_changed     ().connect(sigc::mem_fun(*this, &Self::on_style_changed));
 }
 
 CellRendererPopup::~CellRendererPopup()
